"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.operationInParameterMapper = void 0;
const change_case_1 = require("change-case");
const JsonParameterTypes_1 = require("../domain/JsonParameterTypes");
const JsonSchemaMapperContainer_1 = require("../registries/JsonSchemaMapperContainer");
const generics_1 = require("../utils/generics");
function mapOptions(parameter, options = {}) {
    return {
        ...options,
        groups: parameter.groups,
        groupsName: parameter.groupsName
    };
}
function operationInParameterMapper(jsonParameter, opts) {
    const options = mapOptions(jsonParameter, opts);
    const schemas = { ...(options.schemas || {}) };
    const { type, schema, ...parameter } = (0, JsonSchemaMapperContainer_1.execMapper)("map", jsonParameter, options);
    const jsonSchema = (0, JsonSchemaMapperContainer_1.execMapper)("item", jsonParameter.$schema, {
        ...options,
        ...(0, generics_1.popGenerics)(jsonParameter)
    });
    parameter.required = parameter.required || jsonParameter.get("in") === JsonParameterTypes_1.JsonParameterTypes.PATH;
    const paramOpts = {
        ...options,
        jsonSchema,
        jsonParameter,
        oldSchemas: schemas
    };
    const mapperName = (0, change_case_1.camelCase)(`operationIn ${jsonParameter.get("in")}`);
    if ((0, JsonSchemaMapperContainer_1.hasMapper)(mapperName)) {
        return (0, JsonSchemaMapperContainer_1.execMapper)(mapperName, parameter, paramOpts);
    }
    parameter.schema = jsonSchema;
    return parameter;
}
exports.operationInParameterMapper = operationInParameterMapper;
(0, JsonSchemaMapperContainer_1.registerJsonSchemaMapper)("operationInParameter", operationInParameterMapper);
//# sourceMappingURL=operationInParameterMapper.js.map