"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomKeys = exports.CustomKey = void 0;
const jsonEntityFn_1 = require("./jsonEntityFn");
/**
 * Set a custom key on JsonSchema that is not a part of the official spec.
 *
 * This custom key can only be displayed if the @@getJsonSchema@@ is called with `{customKeys: true}`.
 *
 * @returns {Function}
 * @decorator
 * @validation
 * @property
 * @parameter
 * @schema
 */
function CustomKey(key, value) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store) => {
        store.itemSchema.customKey(key, value);
    });
}
exports.CustomKey = CustomKey;
/**
 * Set a group of custom keys on JsonSchema that is not a part of the official spec.
 *
 * This custom key can only be displayed if the @@getJsonSchema@@ is called with `{customKeys: true}`.
 *
 * @returns {Function}
 * @decorator
 * @validation
 * @property
 * @parameter
 * @schema
 */
function CustomKeys(obj) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store) => {
        Object.entries(obj).forEach(([key, value]) => {
            store.itemSchema.customKey(key, value);
        });
    });
}
exports.CustomKeys = CustomKeys;
//# sourceMappingURL=customKey.js.map