"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOperationsRoutes = void 0;
const getOperationsStores_1 = require("./getOperationsStores");
const JsonOperationRoute_1 = require("../domain/JsonOperationRoute");
const getJsonEntityStore_1 = require("./getJsonEntityStore");
const concatPath_1 = require("./concatPath");
function getOperationsRoutes(token, options = {}) {
    const store = token.isStore ? token : (0, getJsonEntityStore_1.getJsonEntityStore)(token);
    const basePath = (0, concatPath_1.concatPath)(options.basePath, store.path);
    let operationsRoutes = [];
    if (options.withChildren) {
        const children = store.get("childrenControllers", []);
        operationsRoutes = children.reduce((operationsRoutes, token) => {
            return operationsRoutes.concat(getOperationsRoutes(token, {
                ...options,
                basePath
            }));
        }, operationsRoutes);
    }
    return [...(0, getOperationsStores_1.getOperationsStores)(token).values()].reduce((routes, endpoint) => {
        const { operation } = endpoint;
        if (operation) {
            operation.operationPaths.forEach((operationPath) => {
                routes.push(new JsonOperationRoute_1.JsonOperationRoute({
                    basePath,
                    token,
                    endpoint,
                    operationPath
                }));
            });
        }
        return routes;
    }, operationsRoutes);
}
exports.getOperationsRoutes = getOperationsRoutes;
//# sourceMappingURL=getOperationsRoutes.js.map