import { execMapper, registerJsonSchemaMapper } from "../registries/JsonSchemaMapperContainer.js";
import { buildPath } from "../utils/buildPath.js";
import { concatParameters } from "../utils/concatParameters.js";
import { getJsonEntityStore } from "../utils/getJsonEntityStore.js";
import { getJsonPathParameters } from "../utils/getJsonPathParameters.js";
import { getOperationsStores } from "../utils/getOperationsStores.js";
function operationId(path, { store, operationIdFormatter }) {
    return operationIdFormatter(store.parent.schema.get("name") || store.parent.targetName, store.propertyName, path);
}
function pushToPath(paths, { path, method, operation }) {
    return {
        ...paths,
        [path]: {
            ...paths[path],
            [method.toLowerCase()]: operation
        }
    };
}
function removeHiddenOperation(operationStore) {
    return !operationStore.store.get("hidden");
}
function mapOperationPaths({ operationStore, operation }) {
    return [...operationStore.operation.operationPaths.values()]
        .map((operationPath) => {
        return {
            ...operationPath,
            operationStore,
            operation
        };
    })
        .filter(({ method }) => method);
}
function mapOperationInPathParameters(options) {
    return ({ path, method, operation, operationStore }) => {
        return getJsonPathParameters(options.ctrlRootPath, path).map(({ path, parameters }) => {
            path = path ? path : "/";
            parameters = concatParameters(parameters.map(({ type, ...param }) => {
                return {
                    ...param,
                    schema: {
                        type
                    }
                };
            }), operation);
            return {
                operation: {
                    ...operation,
                    parameters,
                    operationId: operation.operationId ||
                        operationId(path, {
                            ...options,
                            store: operationStore
                        })
                },
                method,
                path
            };
        });
    };
}
function mapOperation(options) {
    return (operationStore) => {
        const operation = execMapper("operation", operationStore.operation, options);
        return {
            operation,
            operationStore
        };
    };
}
export function pathsMapper(model, { paths, rootPath, ...options }) {
    const store = getJsonEntityStore(model);
    const ctrlPath = store.path;
    const ctrlRootPath = buildPath(rootPath + ctrlPath);
    options = {
        ...options,
        ctrlRootPath
    };
    return [...getOperationsStores(model).values()]
        .filter(removeHiddenOperation)
        .map(mapOperation(options))
        .flatMap(mapOperationPaths)
        .flatMap(mapOperationInPathParameters(options))
        .reduce(pushToPath, paths);
}
registerJsonSchemaMapper("paths", pathsMapper);
//# sourceMappingURL=pathsMapper.js.map